"use client"

import { useState, useCallback, useEffect } from "react"
import { Button } from "@/components/ui/button"
import { connectWallet } from "../utils/contractInteraction"

export function ConnectWalletButton() {
  const [address, setAddress] = useState<string>("")
  const [isConnecting, setIsConnecting] = useState(false)

  const handleConnectWallet = useCallback(async () => {
    setIsConnecting(true)
    try {
      const result = await connectWallet()
      if (result.success) {
        setAddress(result.address)
      } else {
        alert(result.error)
      }
    } catch (error) {
      console.error("Connection error:", error)
      alert("Failed to connect wallet. See console for details.")
    } finally {
      setIsConnecting(false)
    }
  }, [])

  // Listen for account changes
  useEffect(() => {
    if (typeof window !== "undefined" && window.ethereum) {
      const handleAccountsChanged = (accounts: string[]) => {
        if (accounts.length > 0) {
          setAddress(accounts[0])
        } else {
          setAddress("")
        }
      }

      window.ethereum.on("accountsChanged", handleAccountsChanged)

      // Check if already connected
      window.ethereum.request({ method: "eth_accounts" }).then(handleAccountsChanged).catch(console.error)

      return () => {
        window.ethereum.removeListener("accountsChanged", handleAccountsChanged)
      }
    }
  }, [])

  return (
    <Button
      variant="outline"
      className="bg-blue-500 text-white hover:bg-blue-600 text-xs sm:text-sm md:text-base px-2 py-1 sm:px-3 sm:py-2 font-montserrat tracking-wide"
      onClick={handleConnectWallet}
      disabled={isConnecting}
    >
      {isConnecting
        ? "Connecting..."
        : address
          ? `Connected: ${address.slice(0, 4)}...${address.slice(-4)}`
          : "Connect Wallet"}
    </Button>
  )
}

